//
//  PizarraView.swift
//  Pizarra
//
//  Created by Santiago Pavón on 10/6/15.
//  Copyright (c) 2015 UPM. All rights reserved.
//

import UIKit

protocol PizarraDataSource: class {
    func endIndex() -> Int
    func pointAt(index: Int) -> Point
}

@IBDesignable
class PizarraView: UIView {

    @IBInspectable
    var pathWidth: Double = 3.0
    
    @IBInspectable
    var pathColor: UIColor = UIColor.redColor()
    
    weak var dataSource: PizarraDataSource!
    
    override func drawRect(rect: CGRect) {
        
        if dataSource == nil {return}
        
        let endIndex = dataSource.endIndex()
        
        if endIndex < 0 {
            return
        }
        
        var point = dataSource.pointAt(0)
        
        let path = UIBezierPath()
        
        path.moveToPoint(CGPoint(x: point.x, y: point.y))
        
        for var t = 0 ; t < endIndex ; t++ {
            point = dataSource.pointAt(t)
            
            path.addLineToPoint(CGPoint(x: point.x, y: point.y))
        }
        
        path.lineWidth = CGFloat(pathWidth)
        
        pathColor.set()
        
        path.stroke()
    }
    
    
#if TARGET_INTERFACE_BUILDER
    class FakeDataSource : PizarraDataSource {
    
    func startIndex() -> Double {return 0}
    
    func endIndex() -> Double {return 100}
    
    func pointAt(index: Double) -> Point {
    return Point(x: index, y: index % 25)
    }
    }
    
    var strongDataSource: PizarraDataSource!
    
    override func prepareForInterfaceBuilder() {
    strongDataSource = FakeDataSource()
    dataSource = strongDataSource
    }
#endif
    

}
